/*++

Copyright (c) 2010-2013 ELMOS Co., Ltd.

Module Name:
	EPX64R.h
Abstract:
	EPX-64R API library definitions
Revision History:
	10/06/21	Created.
	11/12/22	Modified response time.
	13/05/01	Support for Windows 8.

--*/

#ifndef EPX64R_H
#define EPX64R_H

#ifdef EPX64R_EXPORTS_
#define EPX64R_API __declspec(dllexport)
#else
#define EPX64R_API __declspec(dllimport)
#endif

//
// Device handle
//
typedef void *EPX64R_HANDLE;

//
// Device status (Return Value)
//
enum {
    EPX64R_OK,
    EPX64R_INVALID_HANDLE,
    EPX64R_DEVICE_NOT_FOUND,
    EPX64R_DEVICE_NOT_OPENED,
	EPX64R_OTHER_ERROR,
	EPX64R_COMMUNICATION_ERROR,
    EPX64R_INVALID_PARAMETER
};

//
// Constants
//
#define EPX64R_PORT0	0x01
#define EPX64R_PORT1	0x02
#define EPX64R_PORT2	0x04
#define EPX64R_PORT3	0x08
#define EPX64R_PORT4	0x10
#define EPX64R_PORT5	0x20
#define EPX64R_PORT6	0x40
#define EPX64R_PORT7	0x80

#ifdef __cplusplus
extern "C" {
#endif

//
// Function definitions
//
EPX64R_API int WINAPI EPX64R_GetNumberOfDevices (int *Number);
EPX64R_API int WINAPI EPX64R_GetSerialNumber (int Index, int *SerialNumber);
EPX64R_API int WINAPI EPX64R_Open (EPX64R_HANDLE *Handle);
EPX64R_API int WINAPI EPX64R_OpenBySerialNumber (int SerialNumber, EPX64R_HANDLE *Handle);
EPX64R_API int WINAPI EPX64R_Close (EPX64R_HANDLE Handle);

EPX64R_API int WINAPI EPX64R_SetDirection (EPX64R_HANDLE Handle, BYTE Direction);
EPX64R_API int WINAPI EPX64R_GetDirection (EPX64R_HANDLE Handle, BYTE *Direction);
EPX64R_API int WINAPI EPX64R_OutputPort (EPX64R_HANDLE Handle, BYTE Port, BYTE Value);
EPX64R_API int WINAPI EPX64R_InputPort (EPX64R_HANDLE Handle, BYTE Port, BYTE *Value);
EPX64R_API int WINAPI EPX64R_SetPortOutputBuffer (EPX64R_HANDLE Handle, BYTE Port, BYTE Value);
EPX64R_API int WINAPI EPX64R_GetPortInputBuffer (EPX64R_HANDLE Handle, BYTE Port, BYTE *Value);
EPX64R_API int WINAPI EPX64R_SetOutputLatch (EPX64R_HANDLE Handle);
EPX64R_API int WINAPI EPX64R_SetInputLatch (EPX64R_HANDLE Handle);

#ifdef __cplusplus
}
#endif

#endif  /* EPX64R_H */